@@ -1,5 +1,5 @@
 """OpenAPI spec validator shortcuts module."""
-from six.moves.urllib import parse
+import urllib.parse
 
 
 def validate_spec_factory(validator_callable):
@@ -10,7 +10,7 @@ def validate_spec_factory(validator_callable):
 
 def validate_spec_url_factory(validator_callable, handlers):
     def validate(url):
-        result = parse.urlparse(url)
+        result = urllib.parse.urlparse(url)
         handler = handlers[result.scheme]
         spec = handler(url)
         return validator_callable(spec, spec_url=url)
